@@ -1,4 +1,4 @@
-from PyGitUp.gitup import GitUp, GitError
+from PyGitUp.gitup import GitUp
 import git
 import os
 import sys
@@ -46,8 +46,8 @@ class BGitUp():
     def __init__(self):
         try:
             self.gitUp = GitUp()
-        except GitError as err:
-            print("GitError: {0}".format(err))
+        except:
+            warn("Make sure you are in a git repository")
             sys.exit(1)
 
     def run(self):
